ContactData class
Contact data properties.
name contact name, for example the first and last name email contact's email address, has to be in the email format phone phone number, has to start with + and the country code, followed by 9 only digit chars userId userId contact user identifier company company contact company name state state contact state, see ContactState for possible values birthday birthday contact birthday date in YYYYMMDD or MMDD fromat streetAddress streetAddress contact street address city city contact city zipCode zipCode contact zip/postal code province province contact province/region country country contact country doubleOptIn doubleOptIn contact double opt-in configuration standardDetails additional contact details, for example address, city, zip code numberDetails map of custom numeric details, values must be integers dateDetails map of custom date details stored as Unix timestamps (in milliseconds)
Constructors
-
ContactData({String? name, String? email, String? phone, String? userId, String? company, ContactState? state, String? birthday, String? streetAddress, String? city, String? zipCode, String? province, String? country, DoubleOptIn? doubleOptIn, Map<
String, String> ? standardDetails, Map<String, int> ? numberDetails, Map<String, int> ? dateDetails})
Properties
- birthday → String?
-
final
- city → String?
-
final
- company → String?
-
final
- country → String?
-
final
-
dateDetails
→ Map<
String, int> ? -
final
- doubleOptIn → DoubleOptIn?
-
final
- email → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String?
-
final
-
numberDetails
→ Map<
String, int> ? -
final
- phone → String?
-
final
- province → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
standardDetails
→ Map<
String, String> ? -
final
- state → ContactState?
-
final
- streetAddress → String?
-
final
- userId → String?
-
final
- zipCode → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited