DoubleOptIn class
Double opt-in configuration. Either the ID of the email to be sent or the Contact’s language to be used in the double opt-in email
emailId id of the email message used for double opt-in, UUID language language code in ISO 639-1 format uppercased
Constructors
- DoubleOptIn({String? emailId, String? language})
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited